@@ -5,6 +5,7 @@ import re
 import shlex
 import signal
 import threading
+import time
 import warnings
 from functools import wraps
 from typing import Dict, Iterable, List, Optional, Set
@@ -12,7 +13,6 @@ from typing import Dict, Iterable, List, Optional, Set
 from localstack import config, constants
 from localstack.config import Directories
 from localstack.runtime import hooks
-from localstack.utils.common import FileListener, chmod_r, mkdir, poll_condition
 from localstack.utils.container_utils.container_client import (
     ContainerException,
     PortMappings,
@@ -22,12 +22,14 @@ from localstack.utils.container_utils.container_client import (
 )
 from localstack.utils.container_utils.docker_cmd_client import CmdDockerClient
 from localstack.utils.docker_utils import DOCKER_CLIENT
-
-# set up logger
-from localstack.utils.generic.file_utils import cache_dir
+from localstack.utils.files import cache_dir, chmod_r, mkdir
+from localstack.utils.functions import call_safe
 from localstack.utils.run import run, to_str
 from localstack.utils.serving import Server
+from localstack.utils.sync import poll_condition
+from localstack.utils.tail import FileListener
 
+# set up logger
 LOG = logging.getLogger(os.path.basename(__file__))
 
 
@@ -231,6 +233,7 @@ def setup_logging(log_level=None):
     logging.getLogger("botocore").setLevel(logging.ERROR)
     logging.getLogger("docker").setLevel(logging.WARNING)
     logging.getLogger("elasticsearch").setLevel(logging.ERROR)
+    logging.getLogger("hpack").setLevel(logging.ERROR)
     logging.getLogger("moto").setLevel(logging.WARNING)
     logging.getLogger("requests").setLevel(logging.WARNING)
     logging.getLogger("s3transfer").setLevel(logging.INFO)
@@ -646,7 +649,7 @@ def configure_container(container: LocalstackContainer):
     container.env_vars["DOCKER_HOST"] = f"unix://{config.DOCKER_SOCK}"
     container.env_vars["HOST_TMP_FOLDER"] = config.dirs.functions  # TODO: rename env var
 
-    # TODO discuss if this should be the default?
+    # TODO this is default now, remove once a considerate time is passed
     # to activate proper signal handling
     container.env_vars["SET_TERM_HANDLER"] = "1"
 
@@ -764,6 +767,7 @@ def start_infra_in_docker_detached(console):
 def wait_container_is_ready(timeout: Optional[float] = None):
     """Blocks until the localstack main container is running and the ready marker has been printed."""
     container_name = config.MAIN_CONTAINER_NAME
+    started = time.time()
 
     def is_container_running():
         return DOCKER_CLIENT.is_container_running(container_name)
@@ -771,29 +775,33 @@ def wait_container_is_ready(timeout: Optional[float] = None):
     if not poll_condition(is_container_running, timeout=timeout):
         return False
 
-    logfile = LocalstackContainer(container_name).logfile
+    stream = DOCKER_CLIENT.stream_container_logs(container_name)
 
-    ready = threading.Event()
-
-    def set_ready_if_marker_found(_line: str):
-        if _line == constants.READY_MARKER_OUTPUT:
-            ready.set()
-
-    # start a tail on the logfile
-    listener = FileListener(logfile, set_ready_if_marker_found)
-    listener.start()
+    # create a timer that will terminate the log stream after the remaining timeout
+    timer = None
+    if timeout:
+        waited = time.time() - started
+        remaining = timeout - waited
+        # check the rare case that the timeout has already been reached
+        if remaining <= 0:
+            stream.close()
+            return False
+        timer = threading.Timer(remaining, stream.close)
+        timer.start()
 
     try:
-        # but also check the existing log in case the container has been running longer
-        with open(logfile, "r") as fd:
-            for line in fd:
-                if constants.READY_MARKER_OUTPUT == line.strip():
-                    return True
+        for line in stream:
+            line = line.decode("utf-8").strip()
+            if line == constants.READY_MARKER_OUTPUT:
+                return True
 
-        # TODO: calculate remaining timeout
-        return ready.wait(timeout)
+        # EOF was reached or the stream was closed
+        return False
     finally:
-        listener.close()
+        call_safe(stream.close)
+        if timer:
+            # make sure the timer is stopped (does nothing if it has already run)
+            timer.cancel()
 
 
 # ---------------
